@@ -36,6 +36,8 @@ __license__ = "Apache License, Version 2.0"
 
 from . import admin
 from . import captcha
+from . import csfr
 
 from .admin import AdminPart
 from .captcha import CaptchaPart
+from .csfr import CSFRPart, csfr_protect, csfr_ensure
