@@ -74,6 +74,8 @@ class Event(base.Base):
 
     @classmethod
     def notify_g(cls, name, handlers = None, arguments = {}):
+        logger = appier.get_logger()
+        logger.debug("Triggering '%s' event ..." % name)
         kwargs = dict(name = name)
         if handlers: kwargs["handler"] = {"$in" : handlers}
         events = cls.find(**kwargs)
@@ -81,6 +83,12 @@ class Event(base.Base):
 
     @appier.operation(name = "Notify")
     def notify(self, arguments = {}, delay = True, owner = None):
+        delay_s = ("a delayed" if delay else "an immediate")
+        logger = appier.get_logger()
+        logger.debug(
+            "Notifying handler '%s' for '%s' in %s fashion ..." %\
+            (self.handler, self.name, delay_s)
+        )
         owner = owner or appier.get_app()
         method = getattr(self, "notify_" + self.handler)
         arguments_m = dict(self.arguments)
@@ -125,9 +133,24 @@ class Event(base.Base):
 
     def notify_http(self, arguments = {}):
         url = arguments.get("url", None)
+        logger = appier.get_logger()
+        logger.debug("Running HTTP notification for '%s' ..." % url)
         return appier.post(url, data_j = arguments)
 
     def notify_mailme(self, arguments = {}):
         import mailme
+        logger = appier.get_logger()
+        logger.debug("Running Mailme notification ...")
         api = mailme.Api()
         return api.send(arguments)
+
+    @appier.operation(name = "Duplicate", factory = True)
+    def duplicate_s(self):
+        cls = self.__class__
+        event = cls(
+            name = self.name,
+            handler = self.handler,
+            arguments = self.arguments
+        )
+        event.save()
+        return event
