@@ -71,7 +71,7 @@ class AdminPart(
         self.layout = "fluid"
         self.theme = "modern"
         self.style = "romantic"
-        self.libs = "latest"
+        self.libs = "current"
 
     def load(self):
         appier.Part.load(self)
@@ -102,6 +102,7 @@ class AdminPart(
         self.owner.lib_loaders["pymongo"] = self._pymongo_loader
         self.owner.lib_loaders["redis"] = self._redis_loader
         self.owner.lib_loaders["jinja2"] = self._jinja2_loader
+        self.owner.lib_loaders["ssl"] = self._ssl_loader
 
         self.logger.debug("Generating admin interfaces ...")
         for model_c in self.models_r:
@@ -118,6 +119,7 @@ class AdminPart(
             (("POST"), "/admin/recover", self.recover_do),
             (("GET"), "/admin/reset", self.reset),
             (("POST"), "/admin/reset", self.reset_do),
+            (("GET"), "/admin/confirm", self.confirm),
             (("GET",), "/admin/options", self.options),
             (("POST",), "/admin/options", self.options_action),
             (("GET",), "/admin/status", self.status),
@@ -277,7 +279,8 @@ class AdminPart(
 
     def recover_do(self):
         identifier = self.field("identifier")
-        try: self.account_c.recover(identifier)
+        send_email = self.field("send_email", True, cast = bool)
+        try: self.account_c.recover(identifier, send_email = send_email)
         except appier.AppierException as error:
             return self.template(
                 "recover.html.tpl",
@@ -294,7 +297,7 @@ class AdminPart(
             mandatory = True,
             not_empty = True
         )
-        self.account_c.validate_token(reset_token)
+        self.account_c.validate_reset(reset_token)
         return self.template(
             "reset.html.tpl",
             next = next,
@@ -325,6 +328,19 @@ class AdminPart(
             next or self.url_for(self.login_route_admin)
         )
 
+    def confirm(self):
+        next = self.field("next")
+        confirmation_token = self.field(
+            "confirmation_token",
+            mandatory = True,
+            not_empty = True
+        )
+        send_email = self.field("send_email", True, cast = bool)
+        self.account_c.confirm(confirmation_token, send_email = send_email)
+        return self.redirect(
+            next or self.url_for(self.login_route_admin)
+        )
+
     def new_account(self):
         if not self.owner.admin_open: raise appier.SecurityError(
             message = "signup not allowed"
@@ -478,6 +494,8 @@ class AdminPart(
     @appier.ensure(token = "admin")
     def test_email(self):
         receiver = appier.conf("TEST_EMAIL", None)
+        receiver = self.field("email", receiver)
+        receiver = self.field("receiver", receiver)
         if not receiver: raise appier.OperationalError(
             message = "No test email defined"
         )
@@ -498,6 +516,8 @@ class AdminPart(
     @appier.ensure(token = "admin")
     def test_event(self):
         name = appier.conf("TEST_EVENT", "test")
+        name = self.field("event", name)
+        name = self.field("name", name)
         models.Event.notify_g(name)
         return self.redirect(
             self.url_for(
@@ -604,7 +624,7 @@ class AdminPart(
         self.content_type("application/octet-stream")
         self.request.set_header(
             "Content-Disposition",
-            "attachment; filename=%s" % file_name
+            "attachment; filename=\"%s\"" % file_name
         )
 
         return file.getvalue()
@@ -754,6 +774,7 @@ class AdminPart(
         # then casts the provided parameters according to metadata
         factory = definition.get("factory", False)
         parameters = definition.cast(parameters)
+        parameters_kw = definition.cast(parameters, keyword = True)
 
         # determines the filter information that is going to be passed
         # to the find operations and retrieves the associated entities
@@ -779,7 +800,8 @@ class AdminPart(
         # performs the requested operation for each of them
         for entity in entities:
             method = getattr(entity, operation)
-            result = method(*parameters)
+            method_kw = appier.legacy.getargspec(method)[2]
+            result = method(**parameters_kw) if method_kw else method(*parameters)
 
         # in case the factory mode is enabled, a new entity has been
         # created and proper redirection must be performed so that the
@@ -1263,6 +1285,12 @@ class AdminPart(
             versions.append(("Jinja2", module.__version__))
         return versions
 
+    def _ssl_loader(self, module):
+        versions = []
+        if hasattr(module, "OPENSSL_VERSION"):
+            versions.append(("SSL", module.OPENSSL_VERSION))
+        return versions
+
     def _attached(self, models):
         return [model for model in models if model.is_attached()]
 
